from setuptools import setup

setup(
    name="borisxdave",
    version="0.2.0",
    description="Boris - Autonomous Project Orchestrator",
    py_modules=["boris", "engine", "git_manager", "prompts", "state", "planner", "config"],
    python_requires=">=3.8",
    entry_points={
        "console_scripts": [
            "boris=boris:main",
        ],
    },
)
